$ ------------------------------------------------------------------------------
$ DISCLAIMER
$
$ The Autoliv simplified retractor model was developed by Autoliv and converted to
$   VPS by ESI in close cooperation within the THUMS USER COMMUNITY 3 (TUC3) 
$   research project. Any use of this retractor model shall be entirely at the 
$   user's own risk and responsibility. 
$
$ University of Munich (LMU), AUDI AG, Autoliv, BMW AG, Daimler AG,
$   Porsche AG, Toyota Motor Corporation, Volkswagen AG and ZF TRW do not
$   assume any responsibility for the validity, accuracy, or applicability of
$   any results obtained from this retractor model and do not assume any
$   liability or responsibility whatsoever for any damage, claims, injury or
$   loss of any kind that may arise from or in connection with any use of,
$   reference to and/or reliance upon this model.
$
$ University of Munich (LMU), AUDI AG, Autoliv, BMW AG, Daimler AG,
$   Porsche AG, Toyota Motor Corporation, Volkswagen AG and ZF TRW ask that the
$   TUC 3 project will be acknowledged under references for any use of this
$   FE model resulting in papers and publications.
$ ==============================================================================
$
$   INFORMATION
$
$   Subject:            Simplified retractor model to be used by 3rd part
$                       without encryption. 
$   Correlation level:  The simpliefied retractor model in general mimics
$                       Autoliv's ordinary retractor model, but details differ
$                       and the correation to physical counterparts is lower
$                       than for Autliv's ordinary retractor models. The
$                       simplified retractor model output has been compared to
$                       component simulations with Autoliv's ordinary models for
$                       different pretensioners, pre-pretensioner, no
$                       pretension, several load levels on one and two levels,
$                       and different webbing-on-spool. Also, the simplified
$                       model was inlcuded in a front sled model. In general,
$                       the simplified model captured the behavior of the
$                       ordinary retractor models and the influence on the
$                       output was small. Details can be found for the ls-dyna model 
$                       in the report
$                       210928_Autoliv_simplified_retractor_comparison_report
$                       (internal) and a brife summary in the public report 
$                       210928_Autoliv_simplified_retractor_model_report.
$                       The conversion to VPS and the correlation to the ls-dyna model
$                       provided by Autoliv are documented in the users manual
$                       Autoliv_simplified_retractor_model_VPS_v1-beta.pdf
$   Release date:       January, 2024
$   Contact:            support.esigmbh@esi-group.com; marcel.jagic@esi-group.com
$   VPS versions:       VPS 2021.06, 2022.04, 2023.01
$   Units:              kg-mm-ms
$   Number range:       Retractor: no. 500000-501000, parameters starts with R1*
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$   BRIEF USER GUIDE
$
$   1) PARAMETERS
$      All parameters are defined in the PYVAR 1: Retractor parameters.
$
$      Parameters to be defined by the user:
$        NAME        DESCRIPTION
$        * R1Rttf    Retractor time-to-fire in ms
$        * R1RPon    Pretensioner flag: 1 = fire or 0 = none
$        * R1RPpow   Pretensioner power: weaker ~0.8, normal ~1.0
$        * R1PPttf   Pre-pretensioner time-to-fire in ms
$        * R1PPfo    Pre-pretensioner force in kN
$        * R1LL1fo   Initial force in kN on first load limiter level
$        * R1LL1d    Payout distance in mm on first load limiter level
$        * R1LL2fo   Initial force in kN on second load limiter level
$        * R1LLup    Load 1imiter function switch flag: 1 = second load level >
$                    first load level, 0 = second load level < first load level
$      Parameters recommended not be changed by the user:
$        NAME        DESCRIPTION
$        * R1RPttf   Pretension time-to-fire in ms, including triggering delay
$        * R1LLttf   Load limiter time-to-fire in ms
$        * R1LL1ed   Payout distans in mm on first load limiter level
$        * R1LL1hi   Max first load limiter level in kN due to progressivity
$        * R1LL2lo   Force in kN from to initiate second load limiter level
$        * R1LL2id   Payout distance in mm to initiate second load limiter level
$        * R1LL2sd   Payout distance in mm to start second load limiter level
$        * R1LL2hi   Max second load limiter level in kN due to progressivity
$
$   2) ATTACHMENTS
$      Part 500300 (ret_MASTER_part) should be tied to the test environment 
$      (which is prepared in the pc-file) and the chain of beams strictly vertical. 
$      Preferable, this chain of beams should remain vertical during the crash event. 
$      The upper patch of part 500300 (ret_MASTER_part) should be placed at the physical
$      retractor location and the distance between this patch and the 1D-
$      element at the top of the chain of beams should be long enough to enable
$      retractor payout. Webbing should be attached to node 500100, and a
$      friction-free slipring placed at node 500181.
$
$   3) RELATED DOCUMENTS
$      Autoliv_simplified_retractor_model_v1-beta.pdf
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                 PYVAR Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
PYVAR /        1
NAME Retractor parameters
# Retractor time-to-fire in ms 
R1Rttf = 10. 
# Pretensioner flag: 1 = fire or 0 = none 
R1RPon = 1. 
# Pretensioner power: weaker ~0.8, normal ~1 
R1RPpow = 0.8 
# Initial force in kN on first load limiter level 
R1LL1fo = 2.2 
# Initial force in kN on second load limiter level 
R1LL2fo = 10. 
# Load 1imiter function switch flag: 1 = second load level   
# first load level, 0 = second load level  first load level 
R1LLup = 0. 
# Payout distance in mm on first load limiter level 
R1LL1d = 1000. 
# Pre-pretensioner force in kN 
R1PPfo = 0.02 
# Pre-pretensioner time-to-fire in ms 
# DEACTIVATED R1PPttf > 0 BECAUSE OF DIFFERENT BEHAVIOR THAN CORRESPONDING MODEL IN LS-DYNA
# USED IN SENSOR 500700, SEE ALSO DOCUMENTATION FOR MORE INFORMATION
# R1PPttf = 0. 
# 
# 
###################### 
# DO NOT CHANGE BELOW 
# 
# Pretension time-to-fire in ms, including triggering delay 
R1RPttf = R1Rttf + 3.000 * R1RPon 
# 
# Load limiter time-to-fire in ms  
R1LLttf = R1RPttf + 12.000 * R1RPon 
# 
# Payout distans in mm on first load limiter level 
R1LL1ed = 40.0 + R1LL1d 
# 
# Max first load limiter level in kN due to progressivity 
R1LL1hi = 0.0015 * R1LL1d + R1LL1fo 
# 
# Force in kN from to initiate second load limiter level 
R1LL2lo = R1LL2fo - 0.1 
# 
# Payout distance in mm to initiate second load limiter level 
R1LL2id = 40.0 + R1LL1d + 20.0 
# 
# Payout distance in mm to start second load limiter level 
R1LL2sd = 41.0 + R1LL1d + 200.0/(10**R1LLup) 
# 
# Max second load limiter level in kN due to progressivity 
R1LL2hi = (10**R1LLup)*0.0004*(1500-R1LL2id)+R1LL2fo 
# Shortened names for VPS cards - DO NOT CHANGE 
Rttf = R1Rttf 
RPon = R1RPon 
RPpow = R1RPpow 
# DEACTIVATED R1PPttf > 0 BECAUSE OF DIFFERENT BEHAVIOR THAN CORRESPONDING MODEL IN LS-DYNA
# PPttf = R1PPttf 
PPfo = R1PPfo 
LL1fo = R1LL1fo 
LL1d = R1LL1d 
LL2fo = R1LL2fo 
LLup = R1LLup 
RPttf = R1RPttf 
LLttf = R1LLttf 
LL1ed = R1LL1ed 
LL1hi = R1LL1hi 
LL2lo = R1LL2lo 
LL2id = R1LL2id 
LL2sd = R1LL2sd 
LL2hi = R1LL2hi 
END_PYVAR
CDATA /  500001   
NAME VPS Autoliv simplified retractor model v1 - beta
Units:     MM-KG-MS
Release:   January 2024
END_CDATA
CDATA /  500002   
NAME ESI QA Check Autoliv simplified retractor model v1 - beta
Date: 2024-01-31
Input Check 2023.0    .............. [ok]
ESI Check 2023.0.1    .............. [ok]
Version Check
   2021.06            .............. [ok]
   2022.04            .............. [ok]
   2023.01            .............. [ok]
END_CDATA
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                 PART Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMATIDNUMPAR
PART  /   500300   SHELL  500400       0       0       0       0
NAME ret_MASTER_part
$#  DTELIM    TSCALF   DTRATIO
        0.                    
$#   TCONT    EPSINI  COULFRICIFRED IE2E
        0.                              
$#       H NINT    OFFSETNTDOF
        1.    5               
$#ORTBLANK      XDIR      YDIR      ZDIR
    0                                   
$#      
END_PART
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500301  SPRING  500401       0       0       0
NAME ret_spring
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#     ARM        Sr        Ss        St
                                        
$#      
END_PART
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500302  SPRING  500402       0       0       0
NAME ret_stroke
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#     ARM        Sr        Ss        St
                                        
$#      
END_PART
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500303  SPRING  500403       0       0       0
NAME ret_load_limiter
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#     ARM        Sr        Ss        St
                                        
$#      
END_PART
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500304  SPRING  500404       0       0       0
NAME ret_ghost
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#     ARM        Sr        Ss        St
                                        
$#      
END_PART
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500321     BAR  500421       0       0       0
NAME ret_spring_damper
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#       A
        0.
$#      
END_PART
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500322     BAR  500422       0       0       0
NAME ret_stroke_damper
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#       A
        0.
$#      
END_PART
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500323     BAR  500423       0       0       0
NAME ret_load_limiter_damper
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#       A
        0.
$#      
END_PART
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500324     BAR  500424       0       0       0
NAME ret_ghost_damper
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#       A
        0.
$#      
END_PART
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500398  SPRING  500498       0       0       0
NAME ret_stiff_joints
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#     ARM        Sr        Ss        St
                                        
$#      
END_PART
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDPRT   ATYPE   IDMAT IDVAMAT IDTHMAT  IDPMAT
PART  /   500399     BAR  500499       0       0       0
NAME ret_ghostbelt
$#  DTELIM    TSCALF   DTRATIO
                              
$#   TCONT    EPSINI  COULFRICIFRED IE2E
                                        
$#       A
        0.
$#      
END_PART
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                  NODE Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
NODE  /   500100              0.              0.          -1200.
NODE  /   500101              0.              0.          -2395.
NODE  /   500102              0.              0.          -1800.
NODE  /   500103              0.              0.          -1400.
NODE  /   500104              0.              0.          -1350.
NODE  /   500105              0.              0.          -1250.
NODE  /   500112              0.              0.          -1800.
NODE  /   500113              0.              0.          -1400.
NODE  /   500114              0.              0.          -1350.
NODE  /   500151              0.              0.           -600.
NODE  /   500152              0.              0.           -600.
NODE  /   500153              0.              0.           -600.
NODE  /   500154              0.              0.           -600.
NODE  /   500155              0.              0.           -600.
NODE  /   500175              0.             20.          -2395.
NODE  /   500176             20.              0.          -2395.
NODE  /   500177              0.              0.          -2375.
NODE  /   500179              0.              0.          -2415.
NODE  /   500180             20.              0.           -600.
NODE  /   500181              0.              0.           -600.
NODE  /   500182            -20.              0.           -600.
NODE  /   500183             20.              0.           -580.
NODE  /   500184              0.              0.           -580.
NODE  /   500185            -20.              0.           -580.
NODE  /   500186             20.              0.           -620.
NODE  /   500187              0.              0.           -620.
NODE  /   500188            -20.              0.           -620.
NODE  /   500195              0.              0.           -600.
NODE  /   500197              0.              0.          -2395.
NODE  /   500200              0.              0.           -600.
$
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$ Bar elements below are the Damping elements for Damping functions
$
$#          IDEL   IDPRT  IDNOD1  IDNOD2
BAR   /   500221  500321  500101  500102
BAR   /   500222  500322  500112  500103
BAR   /   500223  500323  500113  500104
BAR   /   500224  500324  500114  500105
BAR   /   500301  500399  500100  500105
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$ Spring elements below are the Stiffness elements
$
$ Spring
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500201  500301  500101  500102  500175
$
$ Stroke
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500202  500302  500112  500103  500175
$
$ Load Limiter
$$$SPRING/   500203  500303  500106  500105  500175
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500203  500303  500113  500104  500175
$
$ Ghost
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500204  500304  500114  500105  500175
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$ Spring elements below are the zero-length rigid elements for RBODYs
$
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500231  500398  500197  500101  500175
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500232  500398  500102  500112  500175
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500233  500398  500103  500113  500175
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3
SPRING/   500234  500398  500104  500114  500175
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$
$
$
$
$
$
$
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                 ELEMENT Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3  IDNOD4
SHELL /   500281  500300  500181  500184  500183  500180
SHELL /   500282  500300  500181  500184  500185  500182
SHELL /   500283  500300  500181  500187  500186  500180
SHELL /   500284  500300  500181  500187  500188  500182
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDEL   IDPRT  IDNOD1  IDNOD2  IDNOD3  IDNOD4
SHELL /   500285  500300  500197  500179  500176  500176
SHELL /   500286  500300  500197  500177  500176  500176
SHELL /   500287  500300  500197  500175  500176  500176
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                MATERIAL Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500400     100         7.85E-6       0       0       0       0
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_MASTER_part
$        E             Poisson
$#       E     BLANK        NU     BLANK
      210.                 0.3          





$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500401     220            1E-9               0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_spring
$#  NLOADr      FTLr IHtr    RUPLtr    RUPUtr    WALLtr    WALUtNCDOFr    WDMPtr
    500601        1.    0                                            0          
$#  NUNLDr      FTUr     MASSr    NDAMPr      FTDr       Kr0    Frelas       Ktr
    500600        1.     0.001         0        1.        0.        0.          
$#  NLOADs      FTLs IHts    RUPLts    RUPUts    WALLts    WALUtsDOFts    WDMPts
    500600        1.    0                                            0          
$#  NUNLDs      FTUs     MASSs    NDAMPs      FTDs       Ks0    Fselas       Kts
    500600        1.     0.001         0        1.        0.        0.          
$#  NLOADt      FTLt IHtt    RUPLtt    RUPUtt    WALLtt    WALUttDOFtt    WDMPtt
    500600        1.    0                                            0          
$#  NUNLDt      FTUt     MASSt    NDAMPt      FTDt       Kt0    Ftelas       Ktt
    500600        1.     0.001         0        1.        0.        0.          
$#  MLOADr      FMLr IHrr    RUPLrr    RUPUrr    WALLrr    WALUrrDOFrr    WDMPrr
         0        1.    0                                                       
$#  MUNLDr      FMUr     INERr    MDAMPr      FMDr      KMr0     Melar       Krr
         0        1.        1.         0        1.        0.        0.          
$#  MLOADs      FMLs IHrs    RUPLrs    RUPUrs    WALLrs    WALUrsDOFrs    WDMPrs
         0        1.    0                                                       
$#  MUNLDs      FMUs     INERs    MDAMPs      FMDs      KMs0     Melas       Krs
         0        1.        1.         0        1.        0.        0.          
$#  MLOADt      FMLt IHrt    RUPLrt    RUPUrt    WALLrt    WALUrtDOFrt    WDMPrt
         0        1.    0                                                       
$#  MUNLDt      FMUt     INERt    MDAMPt      FMDt      KMt0     Melat       Krt
         0        1.        1.         0        1.        0.        0.          
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500402     220            1E-9               0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_stroke
$#  NLOADr      FTLr IHtr    RUPLtr    RUPUtr    WALLtr    WALUtNCDOFr    WDMPtr
    500602        1.    0                                            0          
$#  NUNLDr      FTUr     MASSr    NDAMPr      FTDr       Kr0    Frelas       Ktr
    500600        1.     0.001         0        1.        0.        0.          
$#  NLOADs      FTLs IHts    RUPLts    RUPUts    WALLts    WALUtsDOFts    WDMPts
    500600        1.    0                                            0          
$#  NUNLDs      FTUs     MASSs    NDAMPs      FTDs       Ks0    Fselas       Kts
    500600        1.     0.001         0        1.        0.        0.          
$#  NLOADt      FTLt IHtt    RUPLtt    RUPUtt    WALLtt    WALUttDOFtt    WDMPtt
    500600        1.    0                                            0          
$#  NUNLDt      FTUt     MASSt    NDAMPt      FTDt       Kt0    Ftelas       Ktt
    500600        1.     0.001         0        1.        0.        0.          
$#  MLOADr      FMLr IHrr    RUPLrr    RUPUrr    WALLrr    WALUrrDOFrr    WDMPrr
         0        1.    0                                                       
$#  MUNLDr      FMUr     INERr    MDAMPr      FMDr      KMr0     Melar       Krr
         0        1.        1.         0        1.        0.        0.          
$#  MLOADs      FMLs IHrs    RUPLrs    RUPUrs    WALLrs    WALUrsDOFrs    WDMPrs
         0        1.    0                                                       
$#  MUNLDs      FMUs     INERs    MDAMPs      FMDs      KMs0     Melas       Krs
         0        1.        1.         0        1.        0.        0.          
$#  MLOADt      FMLt IHrt    RUPLrt    RUPUrt    WALLrt    WALUrtDOFrt    WDMPrt
         0        1.    0                                                       
$#  MUNLDt      FMUt     INERt    MDAMPt      FMDt      KMt0     Melat       Krt
         0        1.        1.         0        1.        0.        0.          
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500403     220            1E-9               0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_load_limiter
$#  NLOADr      FTLr IHtr    RUPLtr    RUPUtr    WALLtr    WALUtNCDOFr    WDMPtr
    500603        1.    0                                            0          
$#  NUNLDr      FTUr     MASSr    NDAMPr      FTDr       Kr0    Frelas       Ktr
    500600        1.    0.0001         0        1.        0.        0.          
$#  NLOADs      FTLs IHts    RUPLts    RUPUts    WALLts    WALUtsDOFts    WDMPts
    500600        1.    0                                            0          
$#  NUNLDs      FTUs     MASSs    NDAMPs      FTDs       Ks0    Fselas       Kts
    500600        1.    0.0001         0        1.        0.        0.          
$#  NLOADt      FTLt IHtt    RUPLtt    RUPUtt    WALLtt    WALUttDOFtt    WDMPtt
    500600        1.    0                                            0          
$#  NUNLDt      FTUt     MASSt    NDAMPt      FTDt       Kt0    Ftelas       Ktt
    500600        1.    0.0001         0        1.        0.        0.          
$#  MLOADr      FMLr IHrr    RUPLrr    RUPUrr    WALLrr    WALUrrDOFrr    WDMPrr
         0        1.    0                                                       
$#  MUNLDr      FMUr     INERr    MDAMPr      FMDr      KMr0     Melar       Krr
         0        1.        1.         0        1.        0.        0.          
$#  MLOADs      FMLs IHrs    RUPLrs    RUPUrs    WALLrs    WALUrsDOFrs    WDMPrs
         0        1.    0                                                       
$#  MUNLDs      FMUs     INERs    MDAMPs      FMDs      KMs0     Melas       Krs
         0        1.        1.         0        1.        0.        0.          
$#  MLOADt      FMLt IHrt    RUPLrt    RUPUrt    WALLrt    WALUrtDOFrt    WDMPrt
         0        1.    0                                                       
$#  MUNLDt      FMUt     INERt    MDAMPt      FMDt      KMt0     Melat       Krt
         0        1.        1.         0        1.        0.        0.          
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500404     220            1E-9               0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_ghost
$#  NLOADr      FTLr IHtr    RUPLtr    RUPUtr    WALLtr    WALUtNCDOFr    WDMPtr
    500604        1.    0                                            0          
$#  NUNLDr      FTUr     MASSr    NDAMPr      FTDr       Kr0    Frelas       Ktr
    500600        1.    0.0001         0        1.        0.        0.          
$#  NLOADs      FTLs IHts    RUPLts    RUPUts    WALLts    WALUtsDOFts    WDMPts
    500600        1.    0                                            0          
$#  NUNLDs      FTUs     MASSs    NDAMPs      FTDs       Ks0    Fselas       Kts
    500600        1.    0.0001         0        1.        0.        0.          
$#  NLOADt      FTLt IHtt    RUPLtt    RUPUtt    WALLtt    WALUttDOFtt    WDMPtt
    500600        1.    0                                            0          
$#  NUNLDt      FTUt     MASSt    NDAMPt      FTDt       Kt0    Ftelas       Ktt
    500600        1.    0.0001         0        1.        0.        0.          
$#  MLOADr      FMLr IHrr    RUPLrr    RUPUrr    WALLrr    WALUrrDOFrr    WDMPrr
         0        1.    0                                                       
$#  MUNLDr      FMUr     INERr    MDAMPr      FMDr      KMr0     Melar       Krr
         0        1.        1.         0        1.        0.        0.          
$#  MLOADs      FMLs IHrs    RUPLrs    RUPUrs    WALLrs    WALUrsDOFrs    WDMPrs
         0        1.    0                                                       
$#  MUNLDs      FMUs     INERs    MDAMPs      FMDs      KMs0     Melas       Krs
         0        1.        1.         0        1.        0.        0.          
$#  MLOADt      FMLt IHrt    RUPLrt    RUPUrt    WALLrt    WALUrtDOFrt    WDMPrt
         0        1.    0                                                       
$#  MUNLDt      FMUt     INERt    MDAMPt      FMDt      KMt0     Melat       Krt
         0        1.        1.         0        1.        0.        0.          
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500421     204            1E-9       0       0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_damper
$#   NLOAD   CMULTloIHYST
         0        1.    0
$#   NUNLD   UNLCMUL     NDAMP   DAMPMUL     NMULT     BLANK
         0        1.    500655        1.         0          
$#       K         C     DLini
      1E-7                    
$#MASSsprg        Ko
    0.0001        0.
$#      Ft        Fc   DLelimt   DLelimc
                  0.     1000.        0.
$ one blank line

$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500422     204            1E-9       0       0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_stroke_damper
$#   NLOAD   CMULTloIHYST
         0        1.    0
$#   NUNLD   UNLCMUL     NDAMP   DAMPMUL     NMULT     BLANK
         0        1.    500656        1.         0          
$#       K         C     DLini
      1E-7                    
$#MASSsprg        Ko
    0.0001        0.
$#      Ft        Fc   DLelimt   DLelimc
                  0.     1000.        0.

$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500423     204            1E-9       0       0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_load_limiter_damper
$#   NLOAD   CMULTloIHYST
         0        1.    0
$#   NUNLD   UNLCMUL     NDAMP   DAMPMUL     NMULT     BLANK
         0        1.    500657        1.         0          
$#       K         C     DLini
      1E-7                    
$#MASSsprg        Ko
    0.0001        0.
$#      Ft        Fc   DLelimt   DLelimc
                  0.     1000.        0.

$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500424     204            1E-9       0       0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_ghost_damper
$#   NLOAD   CMULTloIHYST
         0        1.    0
$#   NUNLD   UNLCMUL     NDAMP   DAMPMUL     NMULT     BLANK
         0        1.    500658        1.         0          
$#       K         C     DLini
      1E-7                    
$#MASSsprg        Ko
    0.0001        0.
$#      Ft        Fc   DLelimt   DLelimc
                  0.     1000.        0.

$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500498     220            1E-9               0       0        
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_stiff
$#  NLOADr      FTLr IHtr    RUPLtr    RUPUtr    WALLtr    WALUtNCDOFr    WDMPtr
    500600        1.    0                                            0          
$#  NUNLDr      FTUr     MASSr    NDAMPr      FTDr       Kr0    Frelas       Ktr
    500600        1.    0.0001    500650        1.        0.        0.          
$#  NLOADs      FTLs IHts    RUPLts    RUPUts    WALLts    WALUtsDOFts    WDMPts
    500600        1.    0                                            0          
$#  NUNLDs      FTUs     MASSs    NDAMPs      FTDs       Ks0    Fselas       Kts
    500600        1.    0.0001    500650        1.        0.        0.          
$#  NLOADt      FTLt IHtt    RUPLtt    RUPUtt    WALLtt    WALUttDOFtt    WDMPtt
    500600        1.    0                                            0          
$#  NUNLDt      FTUt     MASSt    NDAMPt      FTDt       Kt0    Ftelas       Ktt
    500600        1.    0.0001    500650        1.        0.        0.          
$#  MLOADr      FMLr IHrr    RUPLrr    RUPUrr    WALLrr    WALUrrDOFrr    WDMPrr
    500697        1.    0                                                       
$#  MUNLDr      FMUr     INERr    MDAMPr      FMDr      KMr0     Melar       Krr
    500697        1.        1.         0        1.        0.        0.          
$#  MLOADs      FMLs IHrs    RUPLrs    RUPUrs    WALLrs    WALUrsDOFrs    WDMPrs
    500697        1.    0                                                       
$#  MUNLDs      FMUs     INERs    MDAMPs      FMDs      KMs0     Melas       Krs
    500697        1.        1.         0        1.        0.        0.          
$#  MLOADt      FMLt IHrt    RUPLrt    RUPUrt    WALLrt    WALUrtDOFrt    WDMPrt
    500697        1.    0                                                       
$#  MUNLDt      FMUt     INERt    MDAMPt      FMDt      KMt0     Melat       Krt
    500697        1.        1.         0        1.        0.        0.          
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDMAT   MATYP             RHO   ISINT    ISHG  ISTRAT   IFROZ
MATER /   500499     205          1.2E-6       0       0       0       0
$# BLANK                                                     QVM           IDMPD
                                                              1.               0
NAME ret_ghostbelt
$#   NLOADIHYST
    500699    2
$#       H         D     BLANK     BLANK
        0.        0.                    
$#  K_dash       KSI     EPSI0
                 0.1        0.
$#      MU        Ko
      1E-6        0.
$#   EPSIi     EPSIu
     0.015        0.
$ one blank line

$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                 RBODY Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500310               0  500200                 -500700       0      0.
NAME ret_spring_unlock_constraint
        NOD   500101   500102
        END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500311               0  500151                  500701       0      0.
NAME ret_spring_lock_constraint
        NOD   500101   500102
        END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500312               0  500152                 -500701       0      0.
NAME ret_stroke_unlock_constraint
        NOD   500112   500103
        END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500313               0  500153                  500702       0      0.
NAME ret_stroke_lock_constraint
        NOD   500112   500103
        END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500314               0  500154                 -500702       0      0.
NAME ret_load_limiter_release_constraint
        NOD   500113   500104
        END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500315               0  500155                  500702       0      0.
NAME ret_ghost_lock_constraint
        NOD   500114   500105
        END
$#          IDRB   BLANK    ITRBIDNODcog    ICOG           ISENS    IFRA     HRB
RBODY /   500395               0  500195       0               0       0        
NAME Attachment__retractor_functional_model_to_environment
        PART   500300
        END
$#         IDNOD    IFRA   Blank            DISr            DISs            DISt
MASS  /   500113       0                                                        
NAME MASS_0.08kg
$# BLANK              Mx              My              Mz
                    0.08            0.08            0.08
$# BLANK              Ix              Iy              Iz                   Blank
         5.8132789311224 5.8132789311224 5.8132789311224                        
$#         IDNOD    IFRA   Blank            DISr            DISs            DISt
MASS  /   500105       0                                                        
NAME MASS_0.04kg
$# BLANK              Mx              My              Mz
                    0.04            0.04            0.04
$# BLANK              Ix              Iy              Iz                   Blank
        1.831068123557871.831068123557871.83106812355787                        
$#         IDNOD  XYZUVW    IFRA   ISENS
BOUNC /        0  111111       0       0
NAME BOUNC_111111
        NOD   500195
        END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                                 ===========
$                                 THxxx cards
$                                 ===========
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDNOD  ISTMOD
THNOD /   500104        
NAME ret_retractor_payin/out
$#         IDNOD  ISTMOD
THNOD /   500101        
NAME ret_base_node
$#         IDNOD  ISTMOD
THNOD /   500102        
NAME ret_spring_stroke
$#         IDNOD  ISTMOD
THNOD /   500103        
NAME ret_stroke_load_limiter
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IDEL
THELE /   500201
NAME ret_spring
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----$
$#          IDEL
THELE /   500202
NAME ret_stroke
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----$
$#          IDEL
THELE /   500203
NAME ret_load_limiter
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----$
$#          IDEL
THELE /   500204
NAME ret_ghost
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                                  =========                                    
$                                  SENSORING                                    
$                                  =========                                    
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         ISENS    ITYP IREVFLG  ISOFST
SENSOR/   500700       1       1        
NAME ret_spring_unlock
$#         TSENS
              0.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$#         ISENS    ITYP IREVFLG  ISOFST
SENSOR/   500701       1       1        
NAME ret_spring_lock_and_stroke_release
$#         TSENS
        <RPttf >
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$
$ Sensor that locks the stroke, the ghost and releases the load limiter
$
$#         ISENS    ITYP IREVFLG  ISOFST
SENSOR/   500702       1       1        
NAME ret_stroke_lock_ghost_lock_load_limiter_release
$#         TSENS
        <LLttf >
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                          =======================                              
$                          COORDINATE SYSTEM cards                              
$                          =======================                              
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#          IFRA  IFRATY   IAXIS
FRAME /   500175       2       1
NAME ret_reference_coordinate_system
$ 
$  Coordinate system is defined such that the local X-axis is along the pull-in
$  direction of the chain of joints.
$ 
$           Nod1    Nod2    Nod3
$# BLANK     NF1     NF2     NF3
          500197  500177  500175
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500600       3   1000.   0.001      0.      0.       0       0
NAME ret_stiff_function_for_LOADING_UNLOADING_V00
$
$               |----X-vals----||----Y-Vals----|
$                displacement[m]        force[N]
$#                             X               Y
                             -1.      -60000000.
                              0.              0.
                              1.       60000000.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$                                                                               
$                           ========================                            
$                                 CURVE Cards                            
$                           ========================                            
$                                                                               
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500601       0      1.      1.      0.      0.       0       0
NAME ret_spring_LOADING_CURVE
$
$               |----X-vals----||----Y-Vals----|
$               displacement[mm]       force[kN]
$#                             X               Y
                          -1200.         -10000.
                          -1000.<PPfo          >
                              0.<PPfo          >
                             25.             1.5
                             35.              4.
                             40.              8.
                             50.             20.
                END
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500602       6      1.<RPpow >      0.      0.       0       0
NAME ret_stroke
$
$               |----X-vals----||----Y-Vals----|
$               displacement[mm]       force[kN]
$#                             X               Y
                           -250.              0.
                           -225.              0.
                           -200.             1.8
                           -120.             2.5
                            -40.             2.6
                              0.              3.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500603       8      1.      1.      0.      0.       0       0
NAME ret_load_limiter
$
$               |----X-vals----||----Y-Vals----|
$#                             X               Y
                              0.              0.
$:             xvals               yvals
                              2.             0.5
                             15.             1.5
                             40.<LL1fo         >
                <LL1ed         ><LL1hi         >
                <LL2id         ><LL2lo         >
                <LL2sd         ><LL2fo         >
                           1500.<LL2hi         >
$
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500604       3      1.      1.      0.      0.       0       0
NAME ret_ghost
$
$               |----X-vals----||----Y-Vals----|
$               displacement[mm]       force[kN]
$#                             X               Y
                          -1000.         -50000.
                              0.              0.
                           1000.          50000.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500650       2      1.      1.      0.      0.       0       0
NAME ret_damping_curve
$
$               |----X-vals----||----Y-Vals----|
$                  velocity[m/s]        force[N]
$#                             X               Y
                              0.              0.
                           1000.              5.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500655       2      1.      1.      0.      0.       0       0
NAME ret_spring_DAMPING_CURVE
$
$               |----X-vals----||----Y-Vals----|
$                  velocity[m/s]        force[N]
$#                             X               Y
                              0.              0.
                           1000.             35.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500656       2      1.      1.      0.      0.       0       0
NAME ret_stroke_DAMPING_CURVE
$
$               |----X-vals----||----Y-Vals----|
$                  velocity[m/s]        force[N]
$#                             X               Y
                              0.              0.
                           1000.             75.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500657       2      1.      1.      0.      0.       0       0
NAME ret_load_limiter_DAMPING_CURVE
$
$               |----X-vals----||----Y-Vals----|
$                  velocity[m/s]        force[N]
$#                             X               Y
                              0.              0.
                           1000.             15.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500658       2      1.      1.      0.      0.       0       0
NAME ret_ghost_DAMPING_CURVE
$
$               |----X-vals----||----Y-Vals----|
$                  velocity[m/s]        force[N]
$#                             X               Y
                              0.              0.
                           1000.             15.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500697       3      1.      1.      0.      0.       0       0
NAME ret_stiff_ANGULAR_LOADING
$
$               |----X-vals----||----Y-Vals----|
$                  Angle[radian]     Moment[N.m]
$#                             X               Y
                             -1.         -10000.
                              0.              0.
                              1.          10000.
$---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
$#         IDFUN  FUNTYP   SCALX   SCALY  SHIFTX  SHIFTY IFLMEAS   ICOMP
FUNCT /   500699       2      1.      1.      0.      0.       0       0
NAME ret_1D_Ghostbelt
$               |----X-vals----||----Y-Vals----|
$                    Strain in -      Force in N
$#                             X               Y
                              0.              0.
                            0.02             30.
$
